@@ -1,17 +1,18 @@
 import logging
+import sys
 
 import cv2
 
-from smb3_eh_manip.settings import config
+from smb3_eh_manip import settings
 from smb3_eh_manip.computers.opencv_computer import OpencvComputer
 
 
 class EhVcamComputer:
     def __init__(self):
-        self.capture = cv2.VideoCapture(config.getint("app", "video_capture_source"))
+        self.capture = cv2.VideoCapture(settings.get_int("video_capture_source"))
         if not self.capture.isOpened():
             logging.info("Cannot open camera")
-            exit()
+            sys.exit()
         self.capture_template = cv2.imread("data/eh_vcam/captureTrigger.png")
         self.tas_template = cv2.imread("data/eh_vcam/tasTrigger.png")
 
@@ -19,7 +20,7 @@ class EhVcamComputer:
         ret, frame = self.capture.read()
         if not ret:
             logging.warn("Can't receive frame (stream end?). Exiting ...")
-            exit()
+            sys.exit()
         capture_results = list(
             OpencvComputer.locate_all_opencv(self.capture_template, frame)
         )
@@ -35,4 +36,4 @@ class EhVcamComputer:
 
     def terminate(self):
         self.capture.release()
-        cv2.destroyAllWindows()
\ No newline at end of file
+        cv2.destroyAllWindows()
