@@ -1,11 +1,11 @@
 from smb3_eh_manip.computers.opencv_computer import OpencvComputer
-from smb3_eh_manip.settings import config
+from smb3_eh_manip import settings
 
 
 class TwoOneComputer(OpencvComputer):
     def __init__(self):
         super().__init__(
             "twoonevideo",
-            config.get("app", "two_one_video_path"),
-            config.get("app", "two_one_start_frame_image_path"),
-        )
\ No newline at end of file
+            settings.get("two_one_video_path"),
+            settings.get("two_one_start_frame_image_path"),
+        )
