@@ -1,15 +1,13 @@
-from asyncio.log import logger
-from signal import signal, SIGINT
+import logging
 import time
+from signal import signal, SIGINT
 
+from smb3_eh_manip.computers.calibration_computer import CalibrationComputer
+from smb3_eh_manip.computers.eh_computer import EhComputer
+from smb3_eh_manip.computers.eh_vcam_computer import EhVcamComputer
+from smb3_eh_manip.computers.two_one_computer import TwoOneComputer
 from smb3_eh_manip.logging import initialize_logging
-from smb3_eh_manip.settings import config
-from smb3_eh_manip.computers import (
-    EhComputer,
-    EhVcamComputer,
-    CalibrationComputer,
-    TwoOneComputer,
-)
+from smb3_eh_manip import settings
 
 
 def handler(_signum, _frame):
@@ -21,8 +19,9 @@ def handler(_signum, _frame):
 
 def main():
     global computer
+    signal(SIGINT, handler)
     initialize_logging()
-    computer_name = config.get("app", "computer")
+    computer_name = settings.get("computer")
     if computer_name == "eh":
         computer = EhComputer()
     elif computer_name == "twoone":
@@ -32,14 +31,12 @@ def main():
     elif computer_name == "calibration":
         computer = CalibrationComputer()
     else:
-        logger.warn(f"Failed to find computer {computer_name}")
+        logging.warn(f"Failed to find computer {computer_name}")
     while computer is not None:
         start_time = time.time()
         computer.tick()
-        end_time = time.time()
-        logger.debug(f"Took {end_time-start_time}s to tick")
+        logging.debug(f"Took {(time.time()-start_time)*1000:.1f}ms to tick")
 
 
 if __name__ == "__main__":
-    signal(SIGINT, handler)
-    main()
\ No newline at end of file
+    main()
